==> validate-it-0.5.2.tar.gz: validate-it-0.5.2/validate_it/options.py <==
from datetime import datetime
from typing import Union, Callable, Optional, Iterable, List

AnyType = Union[
    int,
    float,
    bool,
    dict,
    list,
    str,
    tuple
]


Amount = Union[
    int,
    float,
    datetime
]


class Options:
    required: bool
    default: Optional[Union[AnyType, Callable]]

    allowed: Optional[Union[Iterable[AnyType], Callable]]

    min_value: Optional[Union[Amount, Callable]]
    max_value: Optional[Union[Amount, Callable]]

    size: Optional[Union[int, Callable]]

    min_length: Optional[Union[int, Callable]]
    max_length: Optional[Union[int, Callable]]

    alias: Optional[Union[str, Callable]]
    rename: Optional[Union[str, Callable]]

    validators: Optional[List[Iterable[Callable]]]

    parser: Optional[Callable]

    def __init__(
        self,
        required: bool = True,
        default: Optional[Union[AnyType, Callable]] = None,
        allowed: Optional[Union[Iterable[AnyType], Callable]] = None,
        min_value: Optional[Union[Amount, Callable]] = None,
        max_value: Optional[Union[Amount, Callable]] = None,
        size: Optional[Union[int, Callable]] = None,
        min_length: Optional[Union[int, Callable]] = None,
        max_length: Optional[Union[int, Callable]] = None,
        alias: Optional[Union[str, Callable]] = None,
        rename: Optional[Union[str, Callable]] = None,
        validators: Optional[Iterable[Callable]] = None,
        parser: Optional[Callable] = None
    ):

        self.required = required
        self.default = default
        self.allowed = allowed
        self.min_value = min_value
        self.max_value = max_value
        self.size = size
        self.min_length = min_length
        self.max_length = max_length
        self.alias = alias
        self.rename = rename
        self.validators = validators
        self.parser = parser

==> validate-it-0.7.3.tar.gz: validate-it-0.7.3/validate_it/options.py <==
from datetime import datetime
from typing import Union, Callable, Optional, Iterable, List

AnyType = Union[
    int,
    float,
    bool,
    dict,
    list,
    str,
    tuple
]


Amount = Union[
    int,
    float,
    datetime
]


class Options:
    required: bool
    default: Optional[Union[AnyType, Callable]]

    allowed: Optional[Union[Iterable[AnyType], Callable]]

    min_value: Optional[Union[Amount, Callable]]
    max_value: Optional[Union[Amount, Callable]]

    size: Optional[Union[int, Callable]]

    min_length: Optional[Union[int, Callable]]
    max_length: Optional[Union[int, Callable]]

    alias: Optional[Union[str, Callable]]
    rename: Optional[Union[str, Callable]]

    validators: Optional[List[Iterable[Callable]]]

    parser: Optional[Callable]

    def __init__(
        self,
        required: bool = True,
        default: Optional[Union[AnyType, Callable]] = None,
        allowed: Optional[Union[Iterable[AnyType], Callable]] = None,
        min_value: Optional[Union[Amount, Callable]] = None,
        max_value: Optional[Union[Amount, Callable]] = None,
        size: Optional[Union[int, Callable]] = None,
        min_length: Optional[Union[int, Callable]] = None,
        max_length: Optional[Union[int, Callable]] = None,
        alias: Optional[Union[str, Callable]] = None,
        rename: Optional[Union[str, Callable]] = None,
        validators: Optional[Iterable[Callable]] = None,
        parser: Optional[Callable] = None,
        serializer: Optional[Callable] = None
    ):

        self.required = required
        self.default = default
        self.allowed = allowed
        self.min_value = min_value
        self.max_value = max_value
        self.size = size
        self.min_length = min_length
        self.max_length = max_length
        self.alias = alias
        self.rename = rename
        self.validators = validators
        self.parser = parser
        self.serializer = serializer

        self.__type__ = None

    def set_type(self, t):
        self.__type__ = t

    def get_type(self):
        return self.__type__


__all__ = [
    "Options"
]
